@@ -25,7 +25,7 @@ class Plugin(Plugin_Base):
         "parse_files": ["md"]
     }
 
-    def __init__(self, config, doc_src_path, site_config, logger = None):
+    def on_init(self, config, doc_src_path, site_config, logger = None):
         '''
             @config a dict object
             @logger teedoc.logger.Logger object
@@ -222,6 +222,8 @@ class Plugin(Plugin_Base):
         if not htmls_blog:
             return True
         blog_url = list(htmls_blog.keys())
+        if len(blog_url) == 0:
+            return True
         index_url = ""
         blog_url = blog_url[0]
         index_url = "{}static/blog_index/index.json".format(self.site_config["site_root_url"])
